@@ -29,8 +29,6 @@
 #include <QTemporaryFile>
 #include <QWidget>
 #include <QWizard>
-#include <amountedit.h>
-#include <creditdebitedit.h>
 
 // ----------------------------------------------------------------------------
 // KDE Headers
@@ -49,29 +47,32 @@
 // ----------------------------------------------------------------------------
 // Project Includes
 
-#include "mymoneymoney.h"
-#include "mymoneyexception.h"
-#include "mymoneytransactionfilter.h"
-#include "mymoneyfile.h"
-#include "mymoneyaccount.h"
-#include "mymoneysecurity.h"
-#include "mymoneyschedule.h"
-#include "mymoneypayee.h"
-#include "mymoneytag.h"
-#include "mymoneyprice.h"
-#include "mymoneystatement.h"
-#include "mymoneyforecast.h"
-#include "mymoneysplit.h"
-#include "mymoneytransaction.h"
-#include "kmymoneysettings.h"
-#include "icons.h"
-#include "storageenums.h"
-#include "mymoneyenums.h"
-#include "kmymoneyplugin.h"
-#include "statusmodel.h"
-#include "journalmodel.h"
-#include "splitmodel.h"
 #include "accountsmodel.h"
+#include "amountedit.h"
+#include "creditdebitedit.h"
+#include "icons.h"
+#include "journalmodel.h"
+#include "kmymoneyplugin.h"
+#include "kmymoneysettings.h"
+#include "mymoneyaccount.h"
+#include "mymoneyenums.h"
+#include "mymoneyexception.h"
+#include "mymoneyfile.h"
+#include "mymoneyforecast.h"
+#include "mymoneymoney.h"
+#include "mymoneypayee.h"
+#include "mymoneyprice.h"
+#include "mymoneyreport.h"
+#include "mymoneyschedule.h"
+#include "mymoneysecurity.h"
+#include "mymoneysplit.h"
+#include "mymoneystatement.h"
+#include "mymoneytag.h"
+#include "mymoneytransaction.h"
+#include "mymoneytransactionfilter.h"
+#include "splitmodel.h"
+#include "statusmodel.h"
+#include "storageenums.h"
 
 #include "kmmyesno.h"
 
@@ -124,7 +125,7 @@ const char* homePageItems[] = {
     kli18n("Budget").untranslatedText(),
     kli18n("Cash Flow").untranslatedText(),
     // insert new items above this comment
-    0,
+    nullptr,
 };
 
 const QString KMyMoneyUtils::homePageItemToString(const int idx)
@@ -139,7 +140,7 @@ const QString KMyMoneyUtils::homePageItemToString(const int idx)
 int KMyMoneyUtils::stringToHomePageItem(const QString& txt)
 {
     int idx = 0;
-    for (idx = 0; homePageItems[idx] != 0; ++idx) {
+    for (idx = 0; homePageItems[idx] != nullptr; ++idx) {
         if (txt == i18n(homePageItems[idx]))
             return idx + 1;
     }
@@ -275,7 +276,7 @@ void KMyMoneyUtils::calculateAutoLoan(const MyMoneySchedule& schedule, MyMoneyTr
     try {
         MyMoneyForecast::calculateAutoLoan(schedule, transaction, balances);
     } catch (const MyMoneyException &e) {
-        KMessageBox::detailedError(0, i18n("Unable to load schedule details"), QString::fromLatin1(e.what()));
+        KMessageBox::detailedError(nullptr, i18n("Unable to load schedule details"), QString::fromLatin1(e.what()));
     }
 }
 
@@ -365,7 +366,7 @@ KXmlGuiWindow* KMyMoneyUtils::mainWindow()
         if (result)
             return result;
     }
-    return 0;
+    return nullptr;
 }
 
 void KMyMoneyUtils::updateWizardButtons(QWizard* wizard)
