@@ -212,7 +212,7 @@ public:
      * This returns the currently implemented highest fix version
      */
     constexpr static int availableFixVersion() {
-        return 5;
+        return 6;
     }
 
     /**
@@ -266,7 +266,7 @@ public:
       *
       * @sa attachStorage()
       */
-    void detachStorage(MyMoneyStorageMgr* const storage = 0);
+    void detachStorage(MyMoneyStorageMgr* const storage = nullptr);
 
     /**
       * This method returns whether a storage is currently attached to
@@ -968,6 +968,11 @@ public:
      */
     ParametersModel* parametersModel() const;
 
+    /**
+     * The file info model instance
+     */
+    ParametersModel* fileInfoModel() const;
+
     /**
      * The online jobs model instance
      */
