@@ -1,6 +1,6 @@
 /*
     SPDX-FileCopyrightText: 2000-2002 Michael Edwardes <mte@users.sourceforge.net>
-    SPDX-FileCopyrightText: 2001-2017 Thomas Baumgart <tbaumgart@kde.org>
+    SPDX-FileCopyrightText: 2001-2019 Thomas Baumgart <tbaumgart@kde.org>
     SPDX-FileCopyrightText: 2001 Felix Rodriguez <frodriguez@users.sourceforge.net>
     SPDX-FileCopyrightText: 2003 Kevin Tambascio <ktambascio@users.sourceforge.net>
     SPDX-FileCopyrightText: 2004-2005 Ace Jones <acejones@users.sourceforge.net>
@@ -28,19 +28,11 @@
 MyMoneyTransaction::MyMoneyTransaction() :
     MyMoneyObject(*new MyMoneyTransactionPrivate)
 {
-    Q_D(MyMoneyTransaction);
-    d->m_nextSplitID = 1;
-    d->m_entryDate = QDate();
-    d->m_postDate = QDate();
 }
 
 MyMoneyTransaction::MyMoneyTransaction(const QString &id) :
     MyMoneyObject(*new MyMoneyTransactionPrivate, id)
 {
-    Q_D(MyMoneyTransaction);
-    d->m_nextSplitID = 1;
-    d->m_entryDate = QDate();
-    d->m_postDate = QDate();
 }
 
 MyMoneyTransaction::MyMoneyTransaction(const MyMoneyTransaction& other) :
@@ -57,7 +49,7 @@ MyMoneyTransaction::MyMoneyTransaction(const QString& id, const MyMoneyTransacti
     if (d->m_entryDate == QDate())
         d->m_entryDate = QDate::currentDate();
 
-    foreach (auto split, d->m_splits)
+    for (auto& split : d->m_splits)
         split.setTransactionId(id);
 }
 
@@ -125,6 +117,17 @@ uint MyMoneyTransaction::splitCount() const
     return d->m_splits.count();
 }
 
+uint MyMoneyTransaction::splitCountWithValue() const
+{
+    uint rc = 0;
+    Q_D(const MyMoneyTransaction);
+    const auto splitCount = d->m_splits.count();
+    for (int split = 0; split < splitCount; ++split) {
+        rc += (d->m_splits[split].value().isZero() ? 0 : 1);
+    }
+    return rc;
+}
+
 QString MyMoneyTransaction::commodity() const
 {
     Q_D(const MyMoneyTransaction);
@@ -135,6 +138,7 @@ void MyMoneyTransaction::setCommodity(const QString& commodityId)
 {
     Q_D(MyMoneyTransaction);
     d->m_commodity = commodityId;
+    d->clearReferences();
 }
 
 QString MyMoneyTransaction::bankID() const
@@ -186,7 +190,7 @@ bool MyMoneyTransaction::accountReferenced(const QString& id) const
 {
     Q_D(const MyMoneyTransaction);
 
-    foreach (const auto split, d->m_splits) {
+    for (const auto& split : d->m_splits) {
         if (split.accountId() == id)
             return true;
     }
@@ -196,16 +200,17 @@ bool MyMoneyTransaction::accountReferenced(const QString& id) const
 void MyMoneyTransaction::addSplit(MyMoneySplit &split)
 {
     if (!split.id().isEmpty())
-        throw MYMONEYEXCEPTION(QString::fromLatin1("Cannot add split with assigned id '%1'").arg(split.id()));
+        throw MYMONEYEXCEPTION(QString::fromLatin1("Cannot add split with assigned id '%1' to transaction %2").arg(split.id(), id()));
 
     if (split.accountId().isEmpty())
-        throw MYMONEYEXCEPTION(QString::fromLatin1("Cannot add split that does not contain an account reference"));
+        throw MYMONEYEXCEPTION(QString::fromLatin1("Cannot add split that does not contain an account reference to transaction %1").arg(id()));
 
     Q_D(MyMoneyTransaction);
     MyMoneySplit newSplit(d->nextSplitID(), split);
     split = newSplit;
     split.setTransactionId(id());
     d->m_splits.append(split);
+    d->clearReferences();
 }
 
 void MyMoneyTransaction::modifySplit(const MyMoneySplit& split)
@@ -213,78 +218,81 @@ void MyMoneyTransaction::modifySplit(const MyMoneySplit& split)
 // This is the other version which allows having more splits referencing
 // the same account.
     if (split.accountId().isEmpty())
-        throw MYMONEYEXCEPTION_CSTRING("Cannot modify split that does not contain an account reference");
+        throw MYMONEYEXCEPTION(QString::fromLatin1("Cannot modify split that does not contain an account reference in transaction %1").arg(id()));
 
     Q_D(MyMoneyTransaction);
     for (auto& it_split : d->m_splits) {
         if (split.id() == it_split.id()) {
             it_split = split;
+            d->clearReferences();
             return;
         }
     }
-    throw MYMONEYEXCEPTION(QString::fromLatin1("Invalid split id '%1'").arg(split.id()));
+    throw MYMONEYEXCEPTION(QString::fromLatin1("Invalid split id '%1' in transaction %2").arg(split.id(), id()));
 }
 
 void MyMoneyTransaction::removeSplit(const MyMoneySplit& split)
 {
     Q_D(MyMoneyTransaction);
-    for (auto end = d->m_splits.size(), i = 0; i < end; ++i) {
+    for (int end = d->m_splits.size(), i = 0; i < end; ++i) {
         if (split.id() == d->m_splits.at(i).id()) {
             d->m_splits.removeAt(i);
+            d->clearReferences();
             return;
         }
     }
 
-    throw MYMONEYEXCEPTION(QString::fromLatin1("Invalid split id '%1'").arg(split.id()));
+    throw MYMONEYEXCEPTION(QString::fromLatin1("Invalid split id '%1' in transaction %2").arg(split.id(), id()));
 }
 
 void MyMoneyTransaction::removeSplits()
 {
     Q_D(MyMoneyTransaction);
     d->m_splits.clear();
-    d->m_nextSplitID = 1;
+    d->clearReferences();
 }
 
 MyMoneySplit MyMoneyTransaction::splitByPayee(const QString& payeeId) const
 {
     Q_D(const MyMoneyTransaction);
-    foreach (const auto split, d->m_splits) {
+    for (const auto& split : d->m_splits) {
         if (split.payeeId() == payeeId)
             return split;
     }
-    throw MYMONEYEXCEPTION(QString::fromLatin1("Split not found for payee '%1'").arg(QString(payeeId)));
+    throw MYMONEYEXCEPTION(QString::fromLatin1("Split not found for payee '%1' in transaction %2").arg(payeeId, id()));
 }
 
 MyMoneySplit MyMoneyTransaction::splitByAccount(const QString& accountId, const bool match) const
 {
     Q_D(const MyMoneyTransaction);
-    foreach (const auto split, d->m_splits) {
+    for (const auto& split : d->m_splits) {
         if ((match == true && split.accountId() == accountId) ||
                 (match == false && split.accountId() != accountId))
             return split;
     }
-    throw MYMONEYEXCEPTION(QString::fromLatin1("Split not found for account %1%2").arg(match ? "" : "!", accountId));
+    throw MYMONEYEXCEPTION(QString::fromLatin1("Split not found for account %1%2 in transaction %3").arg(match ? "" : "!", accountId, id()));
 }
 
 MyMoneySplit MyMoneyTransaction::splitByAccount(const QStringList& accountIds, const bool match) const
 {
     Q_D(const MyMoneyTransaction);
-    foreach (const auto split, d->m_splits) {
+    for (const auto& split : d->m_splits) {
         if ((match == true && accountIds.contains(split.accountId())) ||
                 (match == false && !accountIds.contains(split.accountId())))
             return split;
     }
-    throw MYMONEYEXCEPTION(QString::fromLatin1("Split not found for account  %1%2...%3").arg(match ? "" : "!", accountIds.front(), accountIds.back()));
+    throw MYMONEYEXCEPTION(
+        QString::fromLatin1("Split not found for account  %1%2...%3 in transaction %4").arg(match ? "" : "!", accountIds.front(), accountIds.back(), id()));
 }
 
 MyMoneySplit MyMoneyTransaction::splitById(const QString& splitId) const
 {
     Q_D(const MyMoneyTransaction);
-    foreach (const auto split, d->m_splits) {
+    for (const auto& split : d->m_splits) {
         if (split.id() == splitId)
             return split;
     }
-    throw MYMONEYEXCEPTION(QString::fromLatin1("Split not found for id '%1'").arg(QString(splitId)));
+    throw MYMONEYEXCEPTION(QString::fromLatin1("Split not found for id '%1' in transaction %2").arg(splitId, id()));
 }
 
 QString MyMoneyTransaction::firstSplitID()
@@ -299,7 +307,7 @@ MyMoneyMoney MyMoneyTransaction::splitSum() const
     MyMoneyMoney result;
 
     Q_D(const MyMoneyTransaction);
-    foreach (const auto split, d->m_splits)
+    for (const auto& split : d->m_splits)
         result += split.value();
     return result;
 }
@@ -318,7 +326,7 @@ bool MyMoneyTransaction::isLoanPayment() const
     try {
 
         Q_D(const MyMoneyTransaction);
-        foreach (const auto split, d->m_splits) {
+        for (const auto& split : d->m_splits) {
             if (split.isAmortizationSplit())
                 return true;
         }
@@ -332,7 +340,7 @@ MyMoneySplit MyMoneyTransaction::amortizationSplit() const
     static MyMoneySplit nullSplit;
 
     Q_D(const MyMoneyTransaction);
-    foreach (const auto split, d->m_splits) {
+    for (const auto& split : d->m_splits) {
         if (split.isAmortizationSplit() && split.isAutoCalc())
             return split;
     }
@@ -344,7 +352,7 @@ MyMoneySplit MyMoneyTransaction::interestSplit() const
     static MyMoneySplit nullSplit;
 
     Q_D(const MyMoneyTransaction);
-    foreach (const auto split, d->m_splits) {
+    for (const auto& split : d->m_splits) {
         if (split.isInterestSplit() && split.isAutoCalc())
             return split;
     }
@@ -392,24 +400,11 @@ void MyMoneyTransaction::setImported(bool state)
         deletePair("Imported");
 }
 
-bool MyMoneyTransaction::hasReferenceTo(const QString& id) const
-{
-    Q_D(const MyMoneyTransaction);
-    if (id == d->m_commodity)
-        return true;
-
-    foreach (const auto split, d->m_splits) {
-        if (split.hasReferenceTo(id))
-            return true;
-    }
-    return false;
-}
-
 bool MyMoneyTransaction::hasAutoCalcSplit() const
 {
     Q_D(const MyMoneyTransaction);
 
-    foreach (const auto split, d->m_splits)
+    for (const auto& split : d->m_splits)
         if (split.isAutoCalc())
             return true;
     return false;
@@ -419,13 +414,13 @@ QString MyMoneyTransaction::accountSignature(bool includeSplitCount) const
 {
     Q_D(const MyMoneyTransaction);
     QMap<QString, int> accountList;
-    foreach (const auto split, d->m_splits)
+    for (const auto& split : d->m_splits)
         accountList[split.accountId()] += 1;
 
     QMap<QString, int>::const_iterator it_a;
     QString rc;
-    for (it_a = accountList.constBegin(); it_a != accountList.constEnd(); ++it_a) {
-        if (it_a != accountList.constBegin())
+    for (it_a = accountList.cbegin(); it_a != accountList.cend(); ++it_a) {
+        if (it_a != accountList.cbegin())
             rc += '-';
         rc += it_a.key();
         if (includeSplitCount)
@@ -437,12 +432,16 @@ QString MyMoneyTransaction::accountSignature(bool includeSplitCount) const
 QString MyMoneyTransaction::uniqueSortKey() const
 {
     Q_D(const MyMoneyTransaction);
-    QString year, month, day, key;
-    const auto postdate = postDate();
-    year = year.setNum(postdate.year()).rightJustified(MyMoneyTransactionPrivate::YEAR_SIZE, '0');
-    month = month.setNum(postdate.month()).rightJustified(MyMoneyTransactionPrivate::MONTH_SIZE, '0');
-    day = day.setNum(postdate.day()).rightJustified(MyMoneyTransactionPrivate::DAY_SIZE, '0');
-    key = QString::fromLatin1("%1-%2-%3-%4").arg(year, month, day, d->m_id);
+    return uniqueSortKey(postDate(), d->m_id);
+}
+
+QString MyMoneyTransaction::uniqueSortKey(const QDate& date, const QString& id)
+{
+    QString year, month, day;
+    year = year.setNum(date.year()).rightJustified(MyMoneyTransactionPrivate::YEAR_SIZE, '0');
+    month = month.setNum(date.month()).rightJustified(MyMoneyTransactionPrivate::MONTH_SIZE, '0');
+    day = day.setNum(date.day()).rightJustified(MyMoneyTransactionPrivate::DAY_SIZE, '0');
+    const auto key = QString::fromLatin1("%1-%2-%3-%4").arg(year, month, day, id);
     return key;
 }
 
