@@ -675,8 +675,8 @@ QVariant JournalModel::data(const QModelIndex& idx, int role) const
             case eMyMoney::Split::InvestmentTransactionType::SellShares:
             case eMyMoney::Split::InvestmentTransactionType::ReinvestDividend:
                 if (!split.shares().isZero()) {
-                    return split.price().formatMoney(MyMoneyFile::instance()->currency(transaction.commodity()).tradingSymbol(), d->security(journalEntry).pricePrecision());
-
+                    return split.possiblyCalculatedPrice().formatMoney(MyMoneyFile::instance()->currency(transaction.commodity()).tradingSymbol(),
+                                                                       d->security(journalEntry).pricePrecision());
                 }
                 break;
             default:
@@ -900,7 +900,7 @@ QVariant JournalModel::data(const QModelIndex& idx, int role) const
     case eMyMoney::Model::SplitPriceRole:
     {
         QVariant rc;
-        rc.setValue(split.price());
+        rc.setValue(split.possiblyCalculatedPrice());
         return rc;
     }
 
@@ -1041,7 +1041,7 @@ QVariant JournalModel::data(const QModelIndex& idx, int role) const
         case eMyMoney::Split::InvestmentTransactionType::SellShares:
         case eMyMoney::Split::InvestmentTransactionType::ReinvestDividend:
             if (!split.shares().isZero()) {
-                return QVariant::fromValue(split.price());
+                return QVariant::fromValue(split.possiblyCalculatedPrice());
             }
             return QVariant::fromValue(MyMoneyMoney());
         default:
@@ -1762,14 +1762,14 @@ QModelIndex JournalModel::adjustToFirstSplitIdx(const QModelIndex& index) const
         return {};
     }
 
-    const auto id = index.data(eMyMoney::Model::IdRole).toString();
+    const auto id = index.data(eMyMoney::Model::JournalTransactionIdRole).toString();
 
     // find the first split of this transaction in the journal
     QModelIndex idx;
     int startRow;
     for (startRow = index.row()-1; startRow >= 0; --startRow) {
         idx = this->index(startRow, 0);
-        const auto cid = idx.data(eMyMoney::Model::IdRole).toString();
+        const auto cid = idx.data(eMyMoney::Model::JournalTransactionIdRole).toString();
         if (cid != id)
             break;
     }
