@@ -2,6 +2,7 @@
     SPDX-FileCopyrightText: 2010-2014 Allan Anderson <agander93@gmail.com>
     SPDX-FileCopyrightText: 2016-2018 Łukasz Wojniłowicz <lukasz.wojnilowicz@gmail.com>
     SPDX-FileCopyrightText: 2018-2019 Thomas Baumgart <tbaumgart@kde.org>
+    SPDX-FileCopyrightText: 2021 Dawid Wróbel <me@dawidwrobel.com>
     SPDX-License-Identifier: GPL-2.0-or-later
 */
 
@@ -12,10 +13,6 @@
 // QT Includes
 
 #include <QFile>
-#ifdef IS_APPIMAGE
-#include <QCoreApplication>
-#include <QStandardPaths>
-#endif
 
 // ----------------------------------------------------------------------------
 // KDE Includes
@@ -32,25 +29,18 @@
 #include "statementinterface.h"
 #include "viewinterface.h"
 
-CSVImporter::CSVImporter(QObject *parent, const QVariantList &args)
-    : KMyMoneyPlugin::Plugin(parent, "csvimporter"/*must be the same as X-KDE-PluginInfo-Name*/)
+CSVImporter::CSVImporter(QObject* parent, const KPluginMetaData& metaData, const QVariantList& args)
+    : KMyMoneyPlugin::Plugin(parent, metaData, args)
     , m_action(nullptr)
+    , m_parentWidget(nullptr)
 {
-    Q_UNUSED(args);
-    const auto componentName = QLatin1String("csvimporter");
+    Q_INIT_RESOURCE(csvimporter);
+
+    if (!args.isEmpty()) {
+        m_parentWidget = args.at(0).value<QWidget*>();
+    }
     const auto rcFileName = QLatin1String("csvimporter.rc");
-    setComponentName(componentName, i18n("CSV importer"));
-
-#ifdef IS_APPIMAGE
-    const QString rcFilePath = QString("%1/../share/kxmlgui5/%2/%3").arg(QCoreApplication::applicationDirPath(), componentName, rcFileName);
-    setXMLFile(rcFilePath);
-
-    const QString localRcFilePath = QStandardPaths::standardLocations(QStandardPaths::GenericDataLocation).first() + QLatin1Char('/') + componentName + QLatin1Char('/') + rcFileName;
-    setLocalXMLFile(localRcFilePath);
-#else
     setXMLFile(rcFileName);
-#endif
-
 
     createActions();
     // For information, announce that we have been loaded.
@@ -72,23 +62,9 @@ void CSVImporter::createActions()
     connect(viewInterface(), &KMyMoneyPlugin::ViewInterface::viewStateChanged, action(qPrintable(kpartgui)), &QAction::setEnabled);
 }
 
-QString CSVImporter::formatName() const
+QStringList CSVImporter::formatMimeTypes() const
 {
-    return QLatin1String("CSV");
-}
-
-QString CSVImporter::formatFilenameFilter() const
-{
-    return "*.csv *.txt";
-}
-
-bool CSVImporter::isMyFormat(const QString& filename) const
-{
-    QFile f(filename);
-    return (filename.endsWith(QLatin1String(".csv"), Qt::CaseInsensitive) ||
-        filename.endsWith(QLatin1String(".tsv"), Qt::CaseInsensitive) ||
-        filename.endsWith(QLatin1String(".txt"), Qt::CaseInsensitive))
-        && f.open(QIODevice::ReadOnly | QIODevice::Text);
+    return {"text/csv", "text/tab-separated-values"};
 }
 
 void CSVImporter::startWizardRun()
@@ -98,14 +74,16 @@ void CSVImporter::startWizardRun()
 
 bool CSVImporter::import(const QString& filename)
 {
-    QPointer<CSVWizard> wizard = new CSVWizard(this);
+    QPointer<CSVWizard> wizard = new CSVWizard(m_parentWidget, this);
     wizard->presetFilename(filename);
     auto rc = false;
 
     if ((wizard->exec() == QDialog::Accepted) && wizard) {
         rc =  !statementInterface()->import(wizard->statement(), false).isEmpty();
     }
-    wizard->deleteLater();
+    if (wizard) {
+        wizard->deleteLater();
+    }
     return rc;
 }
 
@@ -114,6 +92,6 @@ QString CSVImporter::lastError() const
     return QString();
 }
 
-K_PLUGIN_FACTORY_WITH_JSON(CSVImporterFactory, "csvimporter.json", registerPlugin<CSVImporter>();)
+K_PLUGIN_CLASS_WITH_JSON(CSVImporter, "csvimporter.json")
 
 #include "csvimporter.moc"
