@@ -1,5 +1,6 @@
 /*
     SPDX-FileCopyrightText: 2017 Łukasz Wojniłowicz <lukasz.wojnilowicz@gmail.com>
+    SPDX-FileCopyrightText: 2021 Dawid Wróbel <me@dawidwrobel.com>
     SPDX-License-Identifier: GPL-2.0-or-later
 */
 
@@ -24,10 +25,10 @@ class GNCImporter : public KMyMoneyPlugin::Plugin, public KMyMoneyPlugin::Storag
     Q_INTERFACES(KMyMoneyPlugin::StoragePlugin)
 
 public:
-    explicit GNCImporter(QObject *parent, const QVariantList &args);
+    explicit GNCImporter(QObject *parent, const KPluginMetaData &metaData, const QVariantList &args);
     ~GNCImporter() override;
 
-    MyMoneyStorageMgr *open(const QUrl &url) override;
+    bool open(const QUrl &url) override;
     bool save(const QUrl &url) override;
     bool saveAs() override;
 
