@@ -56,8 +56,35 @@ protected:
     void sumInvestmentValues(const ReportAccount &account, QList<CashFlowList> &cfList, QList<MyMoneyMoney> &shList) const;
     void constructPerformanceRow(const ReportAccount& account, TableRow& result, CashFlowList &all) const;
     void constructCapitalGainRow(const ReportAccount& account, TableRow& result) const;
-    QString helperROI(const MyMoneyMoney& buys, const MyMoneyMoney& sells, const MyMoneyMoney& startingBal, const MyMoneyMoney& endingBal, const MyMoneyMoney& cashIncome) const;
+    bool ROI(MyMoneyMoney& returnInvestment,
+             const MyMoneyMoney& buys,
+             const MyMoneyMoney& sells,
+             const MyMoneyMoney& reinvestIncome,
+             const MyMoneyMoney& cashIncome,
+             const MyMoneyMoney& startingBalance,
+             const MyMoneyMoney& endingBalance) const;
+    QString helperAROI(const MyMoneyMoney& buys,
+                       const MyMoneyMoney& sells,
+                       const MyMoneyMoney& reinvestIncome,
+                       const MyMoneyMoney& cashIncome,
+                       const MyMoneyMoney& startingBalance,
+                       const MyMoneyMoney& endingBalance,
+                       const QDate& startingDate,
+                       const QDate& endingDate) const;
+    QString helperROI(const MyMoneyMoney& buys,
+                      const MyMoneyMoney& sells,
+                      const MyMoneyMoney& reinvestIncome,
+                      const MyMoneyMoney& cashIncome,
+                      const MyMoneyMoney& startingBalance,
+                      const MyMoneyMoney& endingBalance) const;
+
+    /**
+     * Calculates the extended internal rate of return
+     * @param all list with cash flow items
+     * @return string with extended internal rate of return
+     */
     QString helperXIRR(const CashFlowList& all) const;
+
     void constructSplitsTable();
     bool linkEntries() const final override {
         return true;
