@@ -6,8 +6,6 @@
 
 #include "querytable-test.h"
 
-#include <KLocalizedString>
-
 #include <QFile>
 #include <QTest>
 
@@ -90,11 +88,6 @@ void writeTable(const QueryTable& table, const QString& basename = QString())
     writeTabletoXML(table, basename);
 }
 
-void QueryTableTest::initTestCase()
-{
-    KLocalizedString::setApplicationDomain(QByteArrayLiteral("kmymoney"));
-}
-
 void QueryTableTest::init()
 {
     file = MyMoneyFile::instance();
@@ -659,15 +652,17 @@ void QueryTableTest::testInvestment()
 
         QVERIFY(MyMoneyMoney(rows[1][ListTable::ctExtendedInternalRateOfReturn]) == MyMoneyMoney("1349/10000"));
         QVERIFY(MyMoneyMoney(rows[1][ListTable::ctReturnInvestment]) == MyMoneyMoney("1/10"));
-        QVERIFY(MyMoneyMoney(rows[1][ListTable::ctStartingBalance]) == MyMoneyMoney(100000.00)); // this should stay non-zero to check if investment performance is calculated at non-zero starting balance
+        QVERIFY(MyMoneyMoney(rows[1][ListTable::ctStartingMarketValue])
+                == MyMoneyMoney(100000.00)); // this should stay non-zero to check if investment performance is calculated at non-zero starting market value
 
         QVERIFY(MyMoneyMoney(rows[2][ListTable::ctExtendedInternalRateOfReturn]) == MyMoneyMoney("2501/2500"));
         QVERIFY(MyMoneyMoney(rows[2][ListTable::ctReturnInvestment]) == MyMoneyMoney("323/1250"));
         QVERIFY(MyMoneyMoney(rows[2][ListTable::ctBuys]) == MyMoneyMoney(-95200.00));
         QVERIFY(MyMoneyMoney(rows[2][ListTable::ctSells]) == MyMoneyMoney(119800.00));
-        QVERIFY(MyMoneyMoney(rows[2][ListTable::ctEndingBalance]) == MyMoneyMoney(0.00)); // this should stay zero to check if investment performance is calculated at zero ending balance
+        QVERIFY(MyMoneyMoney(rows[2][ListTable::ctEndingMarketValue])
+                == MyMoneyMoney(0.00)); // this should stay zero to check if investment performance is calculated at zero ending market value
 
-        QVERIFY(MyMoneyMoney(rows[4][ListTable::ctEndingBalance]) == MyMoneyMoney(280000.00));
+        QVERIFY(MyMoneyMoney(rows[4][ListTable::ctEndingMarketValue]) == MyMoneyMoney(280000.00));
 
 #if 0
         // Dump file & reports
@@ -1037,18 +1032,82 @@ public:
                                                 eMyMoney::Report::DetailLevel::Top,
                                                 "Yearly Budgeted vs. Actual", "Default Report")) {}
 
-    void testHelperROI() {
-        // (10 + 50 - 110 + 60 + 70) / (110 - 10)
-        QString result1 = helperROI(MyMoneyMoney(10), MyMoneyMoney(50), MyMoneyMoney(110), MyMoneyMoney(60), MyMoneyMoney(70));
-        QVERIFY(MyMoneyMoney(result1) == MyMoneyMoney(80, 100));
+    void testHelperAROI()
+    {
+        MyMoneyMoney buys(10);
+        MyMoneyMoney sells(50);
+        MyMoneyMoney reinvestIncome(0);
+        MyMoneyMoney cashIncome(70);
+        MyMoneyMoney startingBalance(110);
+        MyMoneyMoney endingBalance(60);
+        QDate startingDate(2023, 1, 1);
+        QDate endingDate(2024, 1, 1);
 
-        // (110 + 50 - 110 + 60 + 70) / (110 - 110)
-        QString result2 = helperROI(MyMoneyMoney(110), MyMoneyMoney(50), MyMoneyMoney(110), MyMoneyMoney(60), MyMoneyMoney(70));
-        QVERIFY(result2 == "");
+        // one year
+        QString result = helperAROI(buys, sells, reinvestIncome, cashIncome, startingBalance, endingBalance, startingDate, endingDate);
+        QCOMPARE(result, MyMoneyMoney(4, 5).convert(10000).toString());
+
+        // two years
+        endingDate = startingDate.addDays(2 * 365);
+        result = helperAROI(buys, sells, reinvestIncome, cashIncome, startingBalance, endingBalance, startingDate, endingDate);
+        QCOMPARE(result, MyMoneyMoney(427, 1250).convert(10000).toString());
+
+        // half year
+        endingDate = startingDate.addDays(365 / 2);
+        result = helperAROI(buys, sells, reinvestIncome, cashIncome, startingBalance, endingBalance, startingDate, endingDate);
+        QCOMPARE(result, MyMoneyMoney(4501, 2000).convert(10000).toString());
+
+        // quarter year
+        endingDate = startingDate.addDays(365 / 4);
+        result = helperAROI(buys, sells, reinvestIncome, cashIncome, startingBalance, endingBalance, startingDate, endingDate);
+        QCOMPARE(result, MyMoneyMoney(11957, 1250).convert(10000).toString());
+
+        // invalid
+        buys = MyMoneyMoney(110);
+        result = helperAROI(buys, sells, reinvestIncome, cashIncome, startingBalance, endingBalance, startingDate, endingDate);
+        QCOMPARE(result, QString());
+    }
+
+    void testHelperROI()
+    {
+        MyMoneyMoney buys(10);
+        MyMoneyMoney sells(50);
+        MyMoneyMoney reinvestIncome(0);
+        MyMoneyMoney cashIncome(70);
+        MyMoneyMoney startingBalance(110);
+        MyMoneyMoney endingBalance(60);
+        QString result1 = helperROI(buys, sells, reinvestIncome, cashIncome, startingBalance, endingBalance);
+        QCOMPARE(result1, MyMoneyMoney(80, 100).convert(10000).toString());
+
+        buys = MyMoneyMoney(110);
+        QString result2 = helperROI(buys, sells, reinvestIncome, cashIncome, startingBalance, endingBalance);
+        QCOMPARE(result2, QString());
+    }
+
+    void testHelperXIRR()
+    {
+        // see https://help.libreoffice.org/latest/de/text/scalc/01/04060118.html
+        CashFlowList all;
+        all.append(CashFlowListItem(QDate(2001, 1, 1), MyMoneyMoney(-10000)));
+        all.append(CashFlowListItem(QDate(2001, 2, 1), MyMoneyMoney(2000)));
+        all.append(CashFlowListItem(QDate(2001, 3, 15), MyMoneyMoney(2500)));
+        all.append(CashFlowListItem(QDate(2001, 5, 12), MyMoneyMoney(5000)));
+        all.append(CashFlowListItem(QDate(2001, 8, 10), MyMoneyMoney(1000)));
+        QString result1 = helperXIRR(all);
+        QCOMPARE(result1, MyMoneyMoney(457, 2500).convert(10000).toString());
     }
 };
 
-void QueryTableTest::testProtectedMethods()
+void QueryTableTest::testAROI()
+{
+    try {
+        QueryTableProtectedTester().testHelperAROI();
+    } catch (const MyMoneyException& e) {
+        QFAIL(e.what());
+    }
+}
+
+void QueryTableTest::testROI()
 {
     try {
         QueryTableProtectedTester().testHelperROI();
@@ -1056,3 +1115,12 @@ void QueryTableTest::testProtectedMethods()
         QFAIL(e.what());
     }
 }
+
+void QueryTableTest::testXIRR()
+{
+    try {
+        QueryTableProtectedTester().testHelperXIRR();
+    } catch (const MyMoneyException& e) {
+        QFAIL(e.what());
+    }
+}
