@@ -147,18 +147,17 @@ void MyMoneyXmlWriterPrivate::writeFileInformation()
     m_writer->writeStartElement(tagName(Tag::FileInfo));
 
     m_writer->writeStartElement(elementName(Element::General::CreationDate));
-    m_writer->writeAttribute(attributeName(Attribute::General::Date), m_file->parametersModel()->itemById(m_file->fixedKey(MyMoneyFile::CreationDate)).value());
+    m_writer->writeAttribute(attributeName(Attribute::General::Date), m_file->fileInfoModel()->itemById(m_file->fixedKey(MyMoneyFile::CreationDate)).value());
     m_writer->writeEndElement();
     m_writer->writeStartElement(elementName(Element::General::LastModifiedDate));
     m_writer->writeAttribute(attributeName(Attribute::General::Date),
-                             m_file->parametersModel()->itemById(m_file->fixedKey(MyMoneyFile::LastModificationDate)).value());
+                             m_file->fileInfoModel()->itemById(m_file->fixedKey(MyMoneyFile::LastModificationDate)).value());
     m_writer->writeEndElement();
     m_writer->writeStartElement(elementName(Element::General::Version));
     m_writer->writeAttribute(attributeName(Attribute::General::ID), QLatin1String("1"));
     m_writer->writeEndElement();
     m_writer->writeStartElement(elementName(Element::General::FixVersion));
-    m_writer->writeAttribute(attributeName(Attribute::General::Date),
-                             m_file->parametersModel()->itemById(m_file->fixedKey(MyMoneyFile::FileFixVersion)).value());
+    m_writer->writeAttribute(attributeName(Attribute::General::ID), m_file->fileInfoModel()->itemById(m_file->fixedKey(MyMoneyFile::FileFixVersion)).value());
     m_writer->writeEndElement();
     m_writer->writeStartElement(elementName(Element::General::ApplicationVersion));
     m_writer->writeAttribute(attributeName(Attribute::General::ID), QLatin1String(VERSION));
@@ -377,7 +376,6 @@ void MyMoneyXmlWriterPrivate::writeAccounts()
     m_writer->writeStartElement(tagName(Tag::Accounts));
 
     m_accountList = m_file->accountsModel()->itemList();
-    QList<MyMoneyAccount>::const_iterator it;
 
     writeAccount(m_file->accountsModel()->itemByIndex(m_file->accountsModel()->assetIndex()));
     writeAccount(m_file->accountsModel()->itemByIndex(m_file->accountsModel()->liabilityIndex()));
@@ -410,9 +408,7 @@ void MyMoneyXmlWriterPrivate::writeSplit(QXmlStreamWriter* writer, const MyMoney
     writer->writeAttribute(attributeName(Attribute::Split::ReconcileFlag), QString::number(static_cast<int>(split.reconcileFlag())));
     writer->writeAttribute(attributeName(Attribute::Split::Value), split.value().toString());
     writer->writeAttribute(attributeName(Attribute::Split::Shares), split.shares().toString());
-    if (!split.price().isZero()) {
-        writer->writeAttribute(attributeName(Attribute::Split::Price), split.price().toString());
-    }
+    writer->writeAttribute(attributeName(Attribute::Split::Price), split.price().toString());
     writer->writeAttribute(attributeName(Attribute::Split::Memo), split.memo());
     writer->writeAttribute(attributeName(Attribute::Split::Account), split.accountId());
     writer->writeAttribute(attributeName(Attribute::Split::Number), split.number());
@@ -712,6 +708,8 @@ void MyMoneyXmlWriterPrivate::writeOnlineJobs()
 
 void MyMoneyXmlWriterPrivate::writeKMyMoney()
 {
+    // init kmm-id
+    m_file->storageId();
     writeFileInformation();
     writeUserInformation();
     writeInstitutions();
@@ -720,7 +718,10 @@ void MyMoneyXmlWriterPrivate::writeKMyMoney()
     writeTags();
     writeAccounts();
     writeTransactions();
-    writeKeyValueContainer(m_writer, m_file->parametersModel()->pairs());
+    QMap<QString, QString> map = m_file->parametersModel()->pairs();
+    // for compatibility, see https://bugs.kde.org/show_bug.cgi?id=498419
+    map[m_file->fixedKey(MyMoneyFile::LastModificationDate)] = m_file->fileInfoModel()->itemById(m_file->fixedKey(MyMoneyFile::LastModificationDate)).value();
+    writeKeyValueContainer(m_writer, map);
     writeSchedules();
     writeSecurities();
     writeCurrencies();
