@@ -1,5 +1,6 @@
 /*
     SPDX-FileCopyrightText: 2018 Łukasz Wojniłowicz <lukasz.wojnilowicz@gmail.com>
+    SPDX-FileCopyrightText: 2021 Dawid Wróbel <me@dawidwrobel.com>
     SPDX-License-Identifier: GPL-2.0-or-later
 */
 
@@ -21,6 +22,7 @@
 class QIODevice;
 
 class MyMoneyStorageMgr;
+class MyMoneyXmlWriter;
 
 class XMLStorage : public KMyMoneyPlugin::Plugin, public KMyMoneyPlugin::StoragePlugin
 {
@@ -28,10 +30,10 @@ class XMLStorage : public KMyMoneyPlugin::Plugin, public KMyMoneyPlugin::Storage
     Q_INTERFACES(KMyMoneyPlugin::StoragePlugin)
 
 public:
-    explicit XMLStorage(QObject *parent, const QVariantList &args);
+    explicit XMLStorage(QObject *parent, const KPluginMetaData &metaData, const QVariantList &args);
     ~XMLStorage() override;
 
-    MyMoneyStorageMgr *open(const QUrl &url) override;
+    bool open(const QUrl &url) override;
     bool save(const QUrl &url) override;
     bool saveAs() override;
     eKMyMoney::StorageType storageType() const override;
@@ -57,7 +59,7 @@ private:
       *
       * @note This method will close the file when it is written.
       */
-    void saveToLocalFile(const QString& localFile, IMyMoneyOperationsFormat* pWriter, bool plaintext, const QString& keyList);
+    void saveToLocalFile(const QString& localFile, MyMoneyXmlWriter* pWriter, bool plaintext, const QString& keyList);
 
     void checkRecoveryKeyValidity();
 
