@@ -322,6 +322,35 @@ QWidget* JournalDelegate::createEditor(QWidget* parent, const QStyleOptionViewIt
 
     if(index.isValid()) {
         d->m_editor = nullptr;
+        // check that no selected transaction references a closed account
+        const auto file = MyMoneyFile::instance();
+        const auto transactionIndexList = d->m_view->selectionModel()->selectedRows();
+        QStringList closedAccounts;
+        std::for_each(transactionIndexList.cbegin(), transactionIndexList.cend(), [&](const QModelIndex idx) -> void {
+            const auto journalEntryIdx = MyMoneyModelBase::mapToBaseSource(idx);
+            const auto journalEntry = file->journalModel()->itemByIndex(journalEntryIdx);
+            const auto splits = journalEntry.transaction().splits();
+            std::for_each(splits.cbegin(), splits.cend(), [&](const MyMoneySplit split) -> void {
+                const auto accountIdx = file->accountsModel()->indexById(split.accountId());
+                if (accountIdx.data(eMyMoney::Model::AccountIsClosedRole).toBool()) {
+                    closedAccounts.append(accountIdx.data(eMyMoney::Model::AccountNameRole).toString());
+                }
+            });
+        });
+        if (!closedAccounts.isEmpty()) {
+            const auto accountList = closedAccounts.join("<br>");
+            const auto details = i18ncp("@info %2 contains list of account names separated by <br>",
+                                        "<qt>Closed account:<br><br>%2</qt>",
+                                        "<qt>Closed accounts:<br><br>%2</qt>",
+                                        closedAccounts.count(),
+                                        accountList);
+            KMessageBox::detailedError(parent,
+                                       i18nc("@info Unable to edit ", "KMyMoney does not support to edit transaction that reference closed accounts."),
+                                       details,
+                                       i18nc("@title:window", "Prevent editing transactions"));
+            return nullptr;
+        }
+
         if(d->m_view->selectionModel()->selectedRows().count() > 1) {
             auto accountId = d->m_view->accountId();
             if (!accountId.isEmpty()) {
@@ -332,8 +361,7 @@ QWidget* JournalDelegate::createEditor(QWidget* parent, const QStyleOptionViewIt
                     d->m_editor = new MultiTransactionEditor(parent, accountId);
                 }
             } else {
-                errorMessage =
-                    i18nc("@info Editing multiple transactions", "The current implementation cannot modify multiple transactions in different accounts.");
+                errorMessage = i18nc("@info Editing multiple transactions", "The current implementation cannot modify multiple transactions in this view.");
                 // Message that multiple edit is only available in ledger (within a single account)
             }
 
@@ -400,7 +428,7 @@ QWidget* JournalDelegate::createEditor(QWidget* parent, const QStyleOptionViewIt
 
         } else {
             if (!errorMessage.isEmpty()) {
-                KMessageBox::information(0, errorMessage);
+                KMessageBox::information(nullptr, errorMessage);
             }
             JournalDelegate* that = const_cast<JournalDelegate*>(this);
             Q_EMIT that->closeEditor(d->m_editor, NoHint);
@@ -487,7 +515,7 @@ void JournalDelegate::paint(QPainter* painter, const QStyleOptionViewItem& optio
         // draw the text items
         if (!opt.text.isEmpty() || (lineCount > 0) || (matchedLineCount > 0)) {
             // check if it is a scheduled transaction and display it as inactive
-            if (MyMoneyFile::baseModel()->baseModel(index) == MyMoneyFile::instance()->schedulesJournalModel()) {
+            if ((MyMoneyFile::baseModel()->baseModel(index) == MyMoneyFile::instance()->schedulesJournalModel()) && !selected) {
                 opt.state &= ~QStyle::State_Enabled;
             }
             cg = (opt.state & QStyle::State_Enabled) ? QPalette::Normal : QPalette::Disabled;
@@ -496,29 +524,31 @@ void JournalDelegate::paint(QPainter* painter, const QStyleOptionViewItem& optio
                 cg = QPalette::Inactive;
             }
 
+            opt.backgroundBrush = opt.palette.base();
             if (selected) {
                 // always use the normal palette since the background is also in normal
                 painter->setPen(opt.palette.color(QPalette::ColorGroup(QPalette::Normal), QPalette::HighlightedText));
+                style->drawPrimitive(QStyle::PE_PanelItemViewItem, &opt, painter, opt.widget);
 
             } else if (erroneous) {
                 painter->setPen(property("transactionErroneousColor").value<QColor>());
+                style->drawPrimitive(QStyle::PE_PanelItemViewRow, &opt, painter, opt.widget);
 
             } else if (matched) {
-                opt.backgroundBrush = opt.palette.base();
                 opt.backgroundBrush.setColor(property("transactionMatchedColor").value<QColor>());
                 opt.palette.setColor(QPalette::Normal, QPalette::Text, property("transactionMatchedColor").value<QColor>());
+                style->drawPrimitive(QStyle::PE_PanelItemViewItem, &opt, painter, opt.widget);
 
             } else if (imported) {
-                opt.backgroundBrush = opt.palette.base();
                 opt.backgroundBrush.setColor(property("transactionImportedColor").value<QColor>());
                 opt.palette.setColor(QPalette::Normal, QPalette::Text, property("transactionImportedColor").value<QColor>());
+                style->drawPrimitive(QStyle::PE_PanelItemViewItem, &opt, painter, opt.widget);
 
             } else {
                 painter->setPen(opt.palette.color(cg, QPalette::Text));
+                style->drawPrimitive(QStyle::PE_PanelItemViewRow, &opt, painter, opt.widget);
             }
 
-            style->drawPrimitive(QStyle::PE_PanelItemViewItem, &opt, painter, opt.widget);
-
             if (opt.state & QStyle::State_Editing) {
                 painter->setPen(opt.palette.color(cg, QPalette::Text));
                 painter->drawRect(textArea.adjusted(0, 0, -1, -1));
@@ -574,9 +604,11 @@ void JournalDelegate::paint(QPainter* painter, const QStyleOptionViewItem& optio
                 QIcon icon;
                 switch (statusRoles[i]) {
                 case eMyMoney::Model::TransactionErroneousRole:
-                case eMyMoney::Model::ScheduleIsOverdueRole:
                     icon = style->proxy()->standardIcon(QStyle::SP_MessageBoxWarning, &option, option.widget);
                     break;
+                case eMyMoney::Model::ScheduleIsOverdueRole:
+                    icon = Icons::get(Icons::Icon::Calendar);
+                    break;
                 case eMyMoney::Model::TransactionIsImportedRole:
                     icon = Icons::get(Icons::Icon::TransactionStateImported);
                     break;
