@@ -181,7 +181,7 @@ public:
             });
         }
 
-        transactionEditor->loadSchedule(m_schedule);
+        transactionEditor->loadSchedule(m_schedule, NewTransactionEditor::EditSchedule);
 
         // setup widget contents
         ui->nameEdit->setText(m_schedule.name());
@@ -448,7 +448,9 @@ KEditScheduleDlg::KEditScheduleDlg(const MyMoneySchedule& schedule, QWidget* par
 
     const auto dateEdit = d->transactionEditor->findChild<QWidget*>("dateEdit");
     if (dateEdit) {
-        connect(d->ui->lastDayInMonthOption, &QCheckBox::stateChanged, dateEdit, &QWidget::setDisabled);
+        connect(d->ui->lastDayInMonthOption, &QCheckBox::stateChanged, dateEdit, [&](int state) {
+            setDisabled(state == Qt::Checked);
+        });
         dateEdit->setDisabled(d->ui->lastDayInMonthOption->isChecked());
     }
 
@@ -598,7 +600,7 @@ void KEditScheduleDlg::newSchedule(const MyMoneyTransaction& _t, eMyMoney::Sched
         committed = true;
         QPointer<KEditScheduleDlg> dlg = new KEditScheduleDlg(schedule, nullptr);
         KMyMoneyMVCCombo::setSubstringSearchForChildren(dlg, !KMyMoneySettings::stringMatchFromStart());
-        if (dlg->exec() == QDialog::Accepted && dlg != 0) {
+        if (dlg->exec() == QDialog::Accepted && dlg != nullptr) {
             MyMoneyFileTransaction ft;
             try {
                 schedule = dlg->schedule();
@@ -649,7 +651,7 @@ void KEditScheduleDlg::editSchedule(const MyMoneySchedule& inputSchedule, bool a
         case eMyMoney::Schedule::Type::Transfer: {
             QScopedPointer<KEditScheduleDlg> dlg(new KEditScheduleDlg(schedule, nullptr));
             KMyMoneyMVCCombo::setSubstringSearchForChildren(dlg.data(), !KMyMoneySettings::stringMatchFromStart());
-            if (dlg->exec() == QDialog::Accepted && dlg != 0) {
+            if (dlg->exec() == QDialog::Accepted && dlg != nullptr) {
                 MyMoneyFileTransaction ft;
                 try {
                     MyMoneySchedule sched = dlg->schedule();
