@@ -211,8 +211,8 @@ void NewTransactionEditor::Private::updateWidgetState()
 
 bool NewTransactionEditor::Private::checkForValidAmount()
 {
-    WidgetHintFrame::hide(ui->creditDebitEdit, i18nc("@info:tooltip", "Enter the amount of the transaction."));
-    WidgetHintFrame::hide(ui->categoryCombo, i18nc("@info:tooltip", "Enter the category or counter account of the transaction."));
+    WidgetHintFrame::hide(ui->creditDebitEdit);
+    WidgetHintFrame::hide(ui->categoryCombo);
     const auto difference = (q->transactionAmount() - (-splitsSum())).abs();
     if (!difference.isZero()) {
         if (splitModel.rowCount() == 0) {
@@ -276,7 +276,7 @@ bool NewTransactionEditor::Private::isDatePostOpeningDate(const QDate& date, con
  */
 bool NewTransactionEditor::Private::postdateChanged(const QDate& date)
 {
-    WidgetHintFrame::hide(ui->dateEdit, i18n("The posting date of the transaction."));
+    WidgetHintFrame::hide(ui->dateEdit);
 
     if (!date.isValid()) {
         WidgetHintFrame::show(ui->dateEdit, i18n("The posting date is invalid."));
@@ -314,7 +314,7 @@ bool NewTransactionEditor::Private::postdateChanged(const QDate& date)
 bool NewTransactionEditor::Private::costCenterChanged(int costCenterIndex)
 {
     bool rc = true;
-    WidgetHintFrame::hide(ui->costCenterCombo, i18n("The cost center this transaction should be assigned to."));
+    WidgetHintFrame::hide(ui->costCenterCombo);
     if (costCenterIndex != -1) {
         if (costCenterRequired && ui->costCenterCombo->currentText().isEmpty()) {
 #ifndef ENABLE_COSTCENTER
@@ -438,7 +438,7 @@ bool NewTransactionEditor::Private::categoryChanged(const QString& accountId)
 bool NewTransactionEditor::Private::numberChanged(const QString& newNumber)
 {
     bool rc = true; // number did change
-    WidgetHintFrame::hide(ui->numberEdit, i18n("The check number used for this transaction."));
+    WidgetHintFrame::hide(ui->numberEdit);
     if (!newNumber.isEmpty()) {
         auto model = MyMoneyFile::instance()->journalModel();
         const QModelIndexList list = model->match(model->index(0, 0), eMyMoney::Model::SplitNumberRole,
@@ -835,7 +835,7 @@ MyMoneyMoney NewTransactionEditor::Private::removeVatSplit()
     }
 
     // remove the tax split
-    splitModel.removeRow(netSplitIdx.row());
+    splitModel.removeRow(taxSplitIdx.row());
 
     return amount;
 }
@@ -850,7 +850,7 @@ void NewTransactionEditor::Private::updateVAT(TaxValueChange amountChanged)
         cleanupHelper(bool* lockVariable)
             : m_lockVariable(lockVariable)
         {
-            *lockVariable = true;
+            *m_lockVariable = true;
         }
         ~cleanupHelper()
         {
@@ -859,7 +859,7 @@ void NewTransactionEditor::Private::updateVAT(TaxValueChange amountChanged)
         bool* m_lockVariable;
     } cleanupHelper(&inUpdateVat);
 
-    const auto categoryId = ui->categoryCombo->getSelected();
+    auto categoryId = ui->categoryCombo->getSelected();
 
     auto taxCategoryId = [&]() {
         if (categoryId.isEmpty()) {
@@ -875,22 +875,32 @@ void NewTransactionEditor::Private::updateVAT(TaxValueChange amountChanged)
         return;
 
     // more splits than category and tax are not supported
-    if (splitModel.rowCount() > 2)
+    if (splitModel.rowCount() > 2) {
         return;
+    }
 
     // in order to do anything, we need an amount
     MyMoneyMoney amount, newAmount;
     amount = ui->creditDebitEdit->value();
-    if (amount.isZero())
+    if (amount.isZero()) {
         return;
-
-    MyMoneyAccount category;
+    }
 
     // If the transaction has a tax and a category split, remove the tax split
     if (splitModel.rowCount() == 2) {
         newAmount = removeVatSplit();
-        if (splitModel.rowCount() == 2) // not removed?
+        if (splitModel.rowCount() == 2) { // not removed?
             return;
+        }
+
+        // categoryId can be empty in case we update the amount
+        // of an already existing split transaction and the VAT
+        // split has just been removed. In that case, the splitModel
+        // contains a single row from which we can extract the
+        // categoryId and continue.
+        if (categoryId.isEmpty()) {
+            categoryId = splitModel.index(0, 0).data(eMyMoney::Model::SplitAccountIdRole).toString();
+        }
 
         // now we have a single split with a category and check if the
         // value has changed and we need to update that split
@@ -909,14 +919,21 @@ void NewTransactionEditor::Private::updateVAT(TaxValueChange amountChanged)
     if (amountChanged == ValueChanged)
         newAmount = amount;
 
-    if (splitModel.rowCount() != 1)
+    // to be able to assign a tax split, the only thing
+    // we should have is the split assigned to the category.
+    // if we have anything else, bail out
+    if (splitModel.rowCount() != 1) {
         return;
+    }
 
+    // create a transaction with a single split
     auto t = q->transaction();
     t.setCommodity(m_transaction.commodity());
+
+    // and add the VAT part
     MyMoneyFile::instance()->updateVAT(t);
 
-    // clear current splits and add them again
+    // keep the split model in sync with the new data
     splitModel.unload();
     for (const auto& split : t.splits()) {
         if ((split.accountId() == taxId) || split.accountId() == categoryId) {
@@ -1270,7 +1287,7 @@ void NewTransactionEditor::setAmountPlaceHolderText(const QAbstractItemModel* mo
                                                model->headerData(JournalModel::Column::Deposit, Qt::Horizontal).toString());
 }
 
-void NewTransactionEditor::loadSchedule(const MyMoneySchedule& schedule)
+void NewTransactionEditor::loadSchedule(const MyMoneySchedule& schedule, ScheduleEditType editType)
 {
     if (schedule.transaction().splitCount() == 0) {
         // new schedule
@@ -1330,7 +1347,11 @@ void NewTransactionEditor::loadSchedule(const MyMoneySchedule& schedule)
 
         for (const auto& split : d->m_transaction.splits()) {
             if (split.id() == d->m_split.id()) {
-                d->ui->dateEdit->setDate(d->m_transaction.postDate());
+                if (editType == EditSchedule) {
+                    d->ui->dateEdit->setDate(d->m_transaction.postDate());
+                } else {
+                    d->ui->dateEdit->setDate(schedule.adjustedNextDueDate());
+                }
 
                 const auto payeeId = split.payeeId();
                 const QModelIndex payeeIdx = MyMoneyFile::instance()->payeesModel()->indexById(payeeId);
