@@ -1,5 +1,5 @@
 /*
-    SPDX-FileCopyrightText: 2007 Thomas Baumgart <Thomas Baumgart <ipwizard@users.sourceforge.net>>
+    SPDX-FileCopyrightText: 2007 Thomas Baumgart <ipwizard@users.sourceforge.net>
     SPDX-FileCopyrightText: 2017 Łukasz Wojniłowicz <lukasz.wojnilowicz@gmail.com>
     SPDX-License-Identifier: GPL-2.0-or-later
 */
@@ -120,9 +120,6 @@ void Wizard::setAccount(const MyMoneyAccount& acc)
     if (!acc.institutionId().isEmpty()) {
         d->m_institutionPage->selectExistingInstitution(acc.institutionId());
     }
-    if (!acc.parentAccountId().isEmpty()) {
-        d->m_hierarchyPage->setParentAccount(acc.parentAccountId());
-    }
 }
 
 MyMoneyMoney Wizard::interestRate() const
@@ -143,10 +140,7 @@ const MyMoneyAccount& Wizard::account()
     d->m_account.setInstitutionId(d->m_institutionPage->institution().id());
     d->m_account.setNumber(d->m_institutionPage->d_func()->ui->m_accountNumber->text());
     d->m_account.setValue("iban", d->m_institutionPage->d_func()->ui->m_iban->text());
-    if (d->m_accountTypePage->d_func()->ui->m_preferredAccount->isChecked())
-        d->m_account.setValue("PreferredAccount", "Yes");
-    else
-        d->m_account.deletePair("PreferredAccount");
+    d->m_account.setValue("PreferredAccount", d->m_accountTypePage->d_func()->ui->m_preferredAccount->isChecked(), false);
 
     d->m_account.setCurrencyId(d->currency().id());
     if (d->m_account.isLoan()) {
@@ -318,7 +312,7 @@ const MyMoneySchedule& Wizard::schedule()
             QList<MyMoneySplit>::const_iterator it;
             MyMoneyMoney factor(moneyBorrowed() ? 1 : -1, 1);
 
-            for (it = additionalSplits.constBegin(); it != additionalSplits.constEnd(); ++it) {
+            for (it = additionalSplits.cbegin(); it != additionalSplits.cend(); ++it) {
                 s = (*it);
                 s.clearId();
                 s.setShares(s.shares() * factor);
@@ -431,7 +425,8 @@ void Wizard::newAccount(MyMoneyAccount& account)
 
 void Wizard::slotPayeeNew(const QString& txt, QString& id)
 {
-    KMyMoneyUtils::newPayee(txt, id);
+    bool ok;
+    std::tie(ok, id) = KMyMoneyUtils::newPayee(txt);
 }
 
 void Wizard::slotAccountNew(MyMoneyAccount& account)
